@@ -4,9 +4,11 @@ from base64 import b64decode
 from typing import List, Type
 
 import click
+
 from memfault_cli.authenticator import Authenticator
 from memfault_cli.chunk import MemfaultChunk
 from memfault_cli.context import MemfaultCliClickContext
+from memfault_cli.deploy import Deployer
 from memfault_cli.upload import (
     AndroidAppSymbolsUploader,
     BugreportUploader,
@@ -35,11 +37,9 @@ click_option_revision = click.option(
 @click.group()
 @click.option("--email", help="Account email to authenticate with")
 @click.password_option(
-    "--password", prompt=False, help="Account password or user API key to authenticate with",
-)
-@click.option(
-    "--project-key", help="Memfault Project Key",
+    "--password", prompt=False, help="Account password or user API key to authenticate with"
 )
+@click.option("--project-key", help="Memfault Project Key")
 @click.option("--org", help="Organization slug")
 @click.option("--project", help="Project slug")
 @click.option("--url", hidden=True)
@@ -48,9 +48,7 @@ def cli(ctx: MemfaultCliClickContext, **kwargs):
     ctx.obj.update(kwargs)
 
 
-def _do_upload_or_raise(
-    ctx: MemfaultCliClickContext, path: str, uploader_cls: Type[Uploader],
-):
+def _do_upload_or_raise(ctx: MemfaultCliClickContext, path: str, uploader_cls: Type[Uploader]):
     authenticator = Authenticator.create_authenticator_given_context_or_raise(ctx)
     ctx.check_required_cli_args(authenticator=authenticator)
 
@@ -220,6 +218,40 @@ def upload_ota_payload(ctx: MemfaultCliClickContext, path: str, **kwargs):
     _do_upload_or_raise(ctx, path, ReleaseArtifactUploader)
 
 
+@cli.command(name="deploy-release")
+@click.option("--release-version", type=str, required=True)
+@click.option("--cohort", type=str, required=True)
+@click.option(
+    "--rollout-percent",
+    type=int,
+    show_default=True,
+    default=100,
+    help="The (randomly sampled) percentage of devices in the Cohort to rollout the release to.",
+)
+@pass_memfault_cli_context
+def deploy_release(
+    ctx: MemfaultCliClickContext, release_version: str, cohort: str, rollout_percent: int, **kwargs
+):
+    """Publish a Release to a Cohort.
+
+    \b
+    Example Firmware OTA Upload:
+    \b
+        $ memfault --email bot@example.com --password user-api-key \\
+                   --org acme-inc --project smart-sink \\
+                   deploy-release \\
+                   --release-version 1.0.0-alpha \\
+                   --cohort default
+    """
+    ctx.obj.update(**kwargs)
+
+    authenticator = Authenticator.create_authenticator_given_context_or_raise(ctx)
+    ctx.check_required_cli_args(authenticator=authenticator)
+
+    deployer = Deployer(ctx=ctx, authenticator=authenticator)
+    deployer.deploy(release_version=release_version, cohort=cohort, rollout_percent=rollout_percent)
+
+
 def _do_post_chunks_or_raise(ctx: MemfaultCliClickContext, chunks: List[bytes]):
     authenticator = Authenticator.create_authenticator_given_context_or_raise(ctx)
     ctx.check_required_cli_args(authenticator=authenticator)
