@@ -4,14 +4,14 @@ import click
 from memfault_cli.authenticator import Authenticator
 
 
-class PackageInfo:
+class PackageInfo:  # noqa: B903 - no data classes in Python 3.6
     def __init__(self, name: str, version_name: str, version_code: str):
         self.name = name
         self.version_name = version_name
         self.version_code = version_code
 
 
-class SoftwareInfo:
+class SoftwareInfo:  # noqa: B903 - no data classes in Python 3.6
     def __init__(self, software_type: str, software_version: str, revision: Optional[str] = None):
         self.software_type = software_type
         self.software_version = software_version
@@ -65,10 +65,6 @@ class MemfaultCliClickContext(object):
     def project_key(self):
         return self._find_obj_or_raise("project_key")
 
-    @property
-    def account(self):
-        return (self.email, self.password)
-
     @property
     def concurrency(self):
         return self._find_obj_or_raise("concurrency")
@@ -89,7 +85,7 @@ class MemfaultCliClickContext(object):
         return SoftwareInfo(software_type=sw_type, software_version=sw_ver, revision=revision)
 
     @property
-    def file_url(self):
+    def file_url(self) -> str:
         FILES_BASE_URL = "https://files.memfault.com"
         url = self.obj.get("url")
         if url is None:
@@ -97,7 +93,7 @@ class MemfaultCliClickContext(object):
         return url
 
     @property
-    def app_url(self):
+    def app_url(self) -> str:
         APP_BASE_URL = "https://app.memfault.com"
         url = self.obj.get("url")
         if url is None:
@@ -105,13 +101,21 @@ class MemfaultCliClickContext(object):
         return url
 
     @property
-    def chunks_url(self):
+    def chunks_url(self) -> str:
         CHUNKS_BASE_URL = "https://chunks.memfault.com"
         url = self.obj.get("url")
         if url is None:
             return CHUNKS_BASE_URL
         return url
 
+    @property
+    def api_url(self) -> str:
+        CHUNKS_BASE_URL = "https://api.memfault.com"
+        url = self.obj.get("url")
+        if url is None:
+            return CHUNKS_BASE_URL
+        return url
+
     @property
     def hardware_version(self):
         return self.obj.get("hardware_version", None)
