@@ -163,11 +163,16 @@ class Uploader:
         extra_request_data = self.post_token_extra_request_data()
         if extra_request_data:
             json_d.update(extra_request_data)
-        check_response(
-            self.session.post(
-                self.entity_url(), json=json_d, **self.authenticator.requests_auth_params()
-            )
+
+        response = self.session.post(
+            self.entity_url(), json=json_d, **self.authenticator.requests_auth_params()
         )
+        # This file had already uploaded (maybe concurrently). Gracefully ignore the error then.
+        if response.status_code == 409:
+            LOG.info(f"{self.file_path}: was already uploaded.")
+            return
+
+        check_response(response)
 
     def _is_elf(self) -> bool:
         with open(self.file_path, "rb") as file:
@@ -332,6 +337,10 @@ class ReleaseArtifactUploader(Uploader):
         return f"{self._projects_base_url()}/releases/ota_payload"
 
     def ui_url(self) -> str:
+        if not self.ctx.software_info or self.ctx.software_info.software_type == "android-build":
+            # In case of Android, the created Release.version may not be the same as the SoftwareVersion.version, in
+            # case build fingerprints are used, the Release.version will be "stripped" (i.e. */*/*:*/*/*:*/*::1.0.0):
+            return f"{self._projects_ui_base_url()}/releases"
         software_version = url_quote(self.ctx.software_info.software_version)
         return f"{self._projects_ui_base_url()}/releases/{software_version}"
 
